@@ -14,8 +14,8 @@
  * limitations under the License.
  */
 
-#ifndef GLOBUS_INCLUDE_GLOBUS_IO_H
-#define GLOBUS_INCLUDE_GLOBUS_IO_H
+#ifndef GLOBUS_GLOBUS_IO_H
+#define GLOBUS_GLOBUS_IO_H
 
 #include "globus_xio.h"
 #include "globus_xio_tcp_driver.h"
@@ -24,7 +24,9 @@
 
 #define GLOBUS_IO_OVER_XIO 1
 
-EXTERN_C_BEGIN
+#ifdef __cplusplus
+extern "C" {
+#endif
 
 #define GLOBUS_IO_MODULE (&globus_l_io_module)
 
@@ -828,6 +830,11 @@ globus_io_compat_get_gsi_driver();
 globus_xio_driver_t
 globus_io_compat_get_file_driver();
 
+globus_result_t
+globus_io_handle_get_xio_handle(
+    globus_io_handle_t *                handle,
+    globus_xio_handle_t *               xio_handle);
+
 globus_result_t
 globus_io_attr_get_xio_attr(
     globus_io_attr_t *                  attr,
@@ -838,8 +845,10 @@ globus_io_attr_set_stack(
     globus_io_attr_t *                  attr,
     globus_xio_stack_t                  stack);
 
-EXTERN_C_END
+#ifdef __cplusplus
+}
+#endif
 
 #include "globus_io_error_hierarchy.h"
 
-#endif
+#endif /* GLOBUS_IO_H */
